@@ -311,7 +311,7 @@ sub flushgeneric {  # Construct the generic code switch
 
    print $indent,"switch ($loopvar) {\n\n";
 
-   for $case (keys %PDLA_DATATYPES) {
+   for $case (PDLA::Types::typesrtkeys()){
 
      $type = $PDLA_DATATYPES{$case};
 
@@ -404,7 +404,7 @@ sub pdlpp_postamble_int {
 qq|
 
 $pref.pm: $src $core/Types.pm
-	$depbuild\$(PERLRUNINST) \"-MPDLA::PP qw/$mod $mod $pref/\" $src
+	$depbuild\$(PERLRUNINST) \"-MPDLA::PP qw[$mod $mod $pref]\" $src
 
 $pref.xs: $pref.pm
 	\$(TOUCH) \$@
@@ -425,7 +425,7 @@ sub pdlpp_postamble {
 qq|
 
 $pref.pm: $src
-	\$(PERL) "-I$w" \"-MPDLA::PP qw/$mod $mod $pref/\" $src
+	\$(PERL) "-I$w" \"-MPDLA::PP qw[$mod $mod $pref]\" $src
 
 $pref.xs: $pref.pm
 	\$(TOUCH) \$@
@@ -433,6 +433,10 @@ $pref.xs: $pref.pm
 $pref.c: $pref.xs
 
 $pref\$(OBJ_EXT): $pref.c
+
+install ::
+	\@echo "Updating PDLA documentation database...";
+	\$(ABSPERLRUN) -e 'exit if \$\$ENV{DESTDIR}; use PDLA::Doc; eval { PDLA::Doc::add_module(q{$mod}); }; ';
 |
 	} (@_)
 }
@@ -760,7 +764,7 @@ sub generate_core_flags {
     # access (read, if set is true then write as well; if postset true then
     #         read first and write new value after that)
     # to piddle's state
-    foreach my $name ( keys %flags ) {
+    foreach my $name ( sort keys %flags ) {
         my $flag = "PDLA_" . ($flags{$name}{FLAG} || uc($name));
         if ( $flags{$name}{set} ) {
             print <<"!WITH!SUBS!";
